
# Slot: mixins




URI: [linkml:slot_definition_mixins](https://w3id.org/linkml/slot_definition_mixins)


## Domain and Range

slot_definition &#8594;  <sub>0..\*</sub> slot_definition

## Parents

 *  is_a: mixins

## Children


## Used by

 * slot_definition
